summaryrefslogtreecommitdiff
path: root/sys/vm/vm_map.c
diff options
context:
space:
mode:
authorAlan Cox <alc@FreeBSD.org>2003-11-14 06:55:11 +0000
committerAlan Cox <alc@FreeBSD.org>2003-11-14 06:55:11 +0000
commitb7b7cd4421372c28fd71547de45b4057a857a967 (patch)
tree9a92610f3323a5ce4ef11b542fdb2e423e74ad93 /sys/vm/vm_map.c
parent614e1f02e8a8df64e2f29008b4c2814dd6a5b929 (diff)
Notes
Diffstat (limited to 'sys/vm/vm_map.c')
-rw-r--r--sys/vm/vm_map.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/vm/vm_map.c b/sys/vm/vm_map.c
index e2c4c8ea538f..ce192419e3ca 100644
--- a/sys/vm/vm_map.c
+++ b/sys/vm/vm_map.c
@@ -1985,10 +1985,10 @@ vm_map_sync(
end = entry->end;
}
/*
* Make a first pass to check for holes.
*/
for (current = entry; current->start < end; current = current->next) {
- if (current->eflags & MAP_ENTRY_IS_SUB_MAP) {
+ if (invalidate && (current->eflags & MAP_ENTRY_USER_WIRED)) {
vm_map_unlock_read(map);
return (KERN_INVALID_ARGUMENT);
}
@@ -1985,10 +1985,10 @@ vm_map_sync(
}
/*
- * Make a first pass to check for holes.
+ * Make a first pass to check for user-wired memory and holes.
*/
for (current = entry; current->start < end; current = current->next) {